@@ -100,9 +100,9 @@ public:
 	 * Get a fully qualified and resolved pathname.
 	 *
 	 * @return pointer to buffer or NULL if invalid.
-	 * @param file path to evaluate.
+	 * @param filename path to evaluate.
 	 * @param buffer to save into.
-	 * @param max size of buffer.
+	 * @param size of buffer.
 	 */
 	const char *getPath(const char *filename, char *buffer, unsigned size);
 
@@ -110,7 +110,7 @@ public:
          * Get and verify partial pathname for file oriented libexec commands.
          *
          * @return pointer to buffer or NULL if invalid.
-         * @param file path to evaluate.
+         * @param filename path to evaluate.
          */
         const char *getFile(const char *filename);
 
@@ -119,16 +119,16 @@ public:
 	 *
 	 * @param voice to set or NULL for default.
 	 */
-	inline void setVoice(const char *v)
-		{voice = v;};
+	inline void setVoice(const char *voice)
+		{voice = voice;};
 
 	/**
 	 * Set the effective audio level for tones...
 	 *
 	 * @param level to set.
 	 */
-	inline void setLevel(Audio::Level l)
-		{level = l;};
+	inline void setLevel(Audio::Level level)
+		{level = level;};
 
 	/**
 	 * Hangup running session...
