@@ -304,6 +304,19 @@ const char *BayonneSession::getExternal(const char *id)
 		id += 8;
 		if(!stricmp(id, "gid") || !stricmp(id, "id") || !stricmp(id, "sid"))
 			return var_sid;
+		else if(!stricmp(id, "index"))
+		{
+			tmp = getTemp();
+			snprintf(tmp, 10, "%d", timeslot);
+			return tmp;
+		}
+		else if(!stricmp(id, "timestamp"))
+		{
+			tmp = getTemp();
+			time(&now);
+			snprintf(tmp, 16, "%ld", now);
+			return tmp;
+		}
 		else if(!stricmp(id, "uid"))
 		{
 			tmp = getTemp();
