@@ -44,11 +44,6 @@ EnglishTranslator("en_us")
 {
 }
 
-unsigned UsEnglishTranslator::saydate(BayonneSession *s, unsigned count, const char *cp)
-{
-	return BayonneTranslator::saydate(s, count, cp);
-}
-
 unsigned UsEnglishTranslator::saytime(BayonneSession *s, unsigned count, const char *cp)
 {
 	return BayonneTranslator::saytime(s, count, cp);
@@ -115,6 +110,78 @@ unsigned EnglishTranslator::saydate(BayonneSession *s, unsigned count, const cha
 	return number(s, count, buf);
 }
 
+unsigned UsEnglishTranslator::saydate(BayonneSession *s, unsigned count, const char *cp)
+{
+        int month, day, year;
+        char buf[8];
+
+        year = month = day = 0;
+
+        if(count > MAX_LIST - 16)
+                return count; 
+
+        if(strchr(cp, '-'))
+        {
+                year = atoi(cp);
+                cp = strchr(cp, '-');
+                if(cp)
+                        month = atoi(++cp);
+                if(cp)
+                        cp = strchr(cp, '-');
+                if(cp)
+                        day = atoi(++cp);
+        } 
+        else if(strchr(cp, '/'))
+        {
+                month = atoi(cp);
+                cp = strchr(cp, '/');
+                if(cp)
+                        day = atoi(++cp);
+                if(cp)
+                        cp = strchr(cp, '/');
+                if(cp)
+                        year = atoi(++cp);
+        }   
+        else if(strchr(cp, '.'))
+        {
+                day = atoi(cp);
+                cp = strchr(cp, '.');
+                if(cp)
+                        month = atoi(++cp);
+                if(cp)
+                        cp = strchr(cp, '.');
+                if(cp)
+                        year = atoi(++cp);
+        }
+        else return count;  
+
+        --month;
+        snprintf(buf, sizeof(buf), "%d", day);
+	count = addItem(s, count, months[month]);
+        count = sayorder(s, count, buf);
+	if(year / 100 == 20 && year % 100 < 10)
+	{
+		count = addItem(s, count, "2");
+		count = addItem(s, count, "thousand");
+		if(year % 100)
+		{
+			count = addItem(s, count, "and");
+			snprintf(buf, sizeof(buf), "%d", year % 100);
+			goto final;
+		}
+		else
+			return count;
+	}
+	snprintf(buf, sizeof(buf), "%d", year / 100);
+	count = number(s, count, buf);
+	if(year % 100 < 10)
+		count = addItem(s, count, "o");
+	snprintf(buf, sizeof(buf), "%d", year % 100);
+final:
+	return number(s, count, buf);
+}
+
+
 unsigned EnglishTranslator::saytime(BayonneSession *s, unsigned count, const char *cp)
 {
         int hour = 0;
