@@ -207,7 +207,7 @@ const char *Checks::chkList(Line *line, ScriptImage *img)
 	if(getMember(line))
 		return "list has no members";
 
-	if(!useKeywords(line, "=prefix=match=extension"))
+	if(!useKeywords(line, "=prefix=match=extension=after"))
 		return "invalid keyword for list";
 
 	cp = getOption(line, &idx);
