@@ -260,7 +260,19 @@ start:
 	BayonneSysexec::startup();
 #endif
 // reload
-	runtime.loadBinder(keyserver.getLast("binding"));
+	cp = keyserver.getLast("binding");
+#ifdef	WIN32
+	if(cp && !stricmp(cp, "default"))
+		cp = "ivrscript1";
+#else
+	if(cp && !stricmp(cp, "default"))
+	{
+		cp = Process::getEnv("BINDING");
+		if(!cp || !*cp)
+			cp = "ivrscript1";
+	}
+#endif
+	runtime.loadBinder(cp);
 	Bayonne::reload();
 	if(!Bayonne::compile_count)
 	{
@@ -300,11 +312,15 @@ static void logging(void)
 
 static void checking(void)
 {
+	const char *cp = keyserver.getLast("binding");
+
 	keyserver.setValue("logging", "debug");
 	logging();
 	if(!Bayonne::getTimeslotCount())
 		Bayonne::allocate(1, dynamic_cast<ScriptCommand *>(&runtime));
-	runtime.loadBinder(keyserver.getLast("binding"));
+	if(cp && !stricmp(cp, "default"))
+		cp = "ivrscript1";
+	runtime.loadBinder(cp);
 	Bayonne::reload();
         if(!Bayonne::compile_count)
         {
